'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pluginScaffolderBackend = require('@backstage/plugin-scaffolder-backend');
var k8sApply = require('k8s-apply');
var fs = require('fs');
var yaml = require('js-yaml');

function _interopNamespace(e) {
	if (e && e.__esModule) return e;
	var n = Object.create(null);
	if (e) {
		Object.keys(e).forEach(function (k) {
			if (k !== 'default') {
				var d = Object.getOwnPropertyDescriptor(e, k);
				Object.defineProperty(n, k, d.get ? d : {
					enumerable: true,
					get: function () { return e[k]; }
				});
			}
		});
	}
	n["default"] = e;
	return Object.freeze(n);
}

var fs__namespace = /*#__PURE__*/_interopNamespace(fs);
var yaml__namespace = /*#__PURE__*/_interopNamespace(yaml);

const path = require("path");
const deployKubernetesAction = () => {
  return pluginScaffolderBackend.createTemplateAction({
    id: "deploy:kubernetes",
    schema: {
      input: {
        required: ["manifest", "authToken", "clusterUrl"],
        type: "object",
        properties: {
          manifest: {
            type: "string",
            description: "The Kubernetes manifest object"
          },
          authToken: {
            type: "string",
            description: "Authentication token to access the Kubernetes cluster"
          },
          clusterUrl: {
            type: "string",
            description: "URL of the Kubernetes cluster"
          }
        }
      }
    },
    async handler(ctx) {
      const { manifest, authToken, clusterUrl } = ctx.input;
      try {
        let manifestYaml = "";
        const manifestPath = path.resolve(manifest);
        try {
          manifestYaml = await fs__namespace.promises.readFile(manifestPath, {
            encoding: "utf-8"
          });
        } catch (fileError) {
          ctx.logger.error(`Error reading file: ${manifest}`, fileError);
          throw fileError;
        }
        let manifestObject;
        try {
          manifestObject = yaml__namespace.load(manifestYaml);
        } catch (yamlError) {
          ctx.logger.error("Error parsing YAML content", yamlError);
          throw yamlError;
        }
        const response = await k8sApply.applyObject(manifestObject, {
          server: clusterUrl,
          token: authToken
        });
        ctx.logger.info(`Deployment response: ${JSON.stringify(response)}`);
      } catch (error) {
        ctx.logger.error(`Deployment failed: ${error}`);
        throw error;
      }
    }
  });
};

exports.deployKubernetesAction = deployKubernetesAction;
//# sourceMappingURL=index.cjs.js.map
